VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
  Persistable = 0  'NotPersistable
  DataBindingBehavior = 0  'vbNone
  DataSourceBehavior  = 0  'vbNone
  MTSTransactionMode  = 0  'NotAnMTSObject
END
Attribute VB_Name = "CSysInfo"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = False
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = False
'*********************************************************************
' Class:        CSysInfo
' Author:       Craig Jasper, Jr.
' Machine:      CRAIG [ID: CP4850] | Windows 2000 Server.
' Notes:        Written in VB6 Enterprise Edition with
'               SP4 installed. Some parts of this class
'               were written by Karl E. Peterson.
'*********************************************************************

Option Explicit

Private Declare Function GetVersionEx Lib _
"kernel32" Alias "GetVersionExA" _
(lpVersionInformation As OSVERSIONINFO) As Long

Private Type OSVERSIONINFO
  dwOSVersionInfoSize  As Long
  dwMajorVersion       As Long
  dwMinorVersion       As Long
  dwBuildNumber        As Long
  dwPlatformId         As Long
  szCSDVersion         As String * 128
End Type

Private Const VER_PLATFORM_WIN32s = 0
Private Const VER_PLATFORM_WIN32_WINDOWS = 1
Private Const VER_PLATFORM_WIN32_NT = 2

Private Const MAX_PATH = 260

Private m_OS     As OSVERSIONINFO
Private m_bloNT  As Boolean
Private m_blo2K  As Boolean
Private m_blo95  As Boolean
Private m_blo98  As Boolean

Private Sub Class_Initialize()
  Dim nNull As Long
   
  m_OS.dwOSVersionInfoSize = Len(m_OS)
  Call GetVersionEx(m_OS)
   
  ' Trim CSDVersion string at first null:
  nNull = InStr(m_OS.szCSDVersion, vbNullChar)
   
  If nNull > 1 Then
    m_OS.szCSDVersion = Left(m_OS.szCSDVersion, _
       nNull - 1)
  ElseIf nNull = 1 Then
    m_OS.szCSDVersion = ""
  End If
  
  ' Determine and store values likely to be
  ' referenced often. VB4/32 will not run
  ' in Win32s, so needn't test for that...
  Select Case m_OS.dwPlatformId
    Case VER_PLATFORM_WIN32_WINDOWS
      If m_OS.dwMinorVersion >= 10 Then
        m_blo95 = False
        m_blo98 = True
      Else
        m_blo95 = True
        m_blo98 = False
      End If
      m_bloNT = False
    Case VER_PLATFORM_WIN32_NT
      m_blo95 = False
      m_blo98 = False
      m_bloNT = True
      m_blo2K = (m_OS.dwMajorVersion >= 5)
  End Select
End Sub

Public Property Get MajorVersion() As Long
  MajorVersion = m_OS.dwMajorVersion
End Property

Public Property Get MinorVersion() As Long
  MinorVersion = m_OS.dwMinorVersion
End Property

Public Property Get BuildNumber() As Long
  BuildNumber = WordLo(m_OS.dwBuildNumber)
End Property

Public Property Get PlatformID() As Long
  PlatformID = m_OS.dwPlatformId
End Property

Public Property Get IsWin2K() As Boolean
  IsWin2K = m_blo2K
End Property

Public Property Get IsWinNT() As Boolean
  IsWinNT = m_bloNT
End Property

Public Property Get IsWin9x() As Boolean
  IsWin9x = (m_blo95 Or m_blo98)
End Property

Public Property Get IsWin95() As Boolean
  IsWin95 = m_blo95
End Property

Public Property Get IsWin98() As Boolean
  IsWin98 = m_blo98
End Property

Public Property Get Platform() As String
  If m_blo95 Then
    Platform = "Windows 95"
  ElseIf m_blo98 Then
    Platform = "Windows 98"
  ElseIf m_blo2K Then
    Platform = "Windows 2000"
  Else 'm_bloNT
    Platform = "Windows NT"
  End If
End Property

Public Property Get Version() As String
  ' Build and return version info string:
  Version = Platform & _
     " v" & MajorVersion & _
     "." & MinorVersion & _
     ", Build " & BuildNumber
End Property

Public Property Get CSDVersion() As String
  CSDVersion = Trim(m_OS.szCSDVersion)
End Property

Private Function WordLo(LongIn As Long) As Integer
  ' Low word retrieved by masking off high word.
  ' If low word is too large, twiddle sign bit...
  If (LongIn And &HFFFF&) > &H7FFF Then
    WordLo = (LongIn And &HFFFF&) - &H10000
  Else
    WordLo = LongIn And &HFFFF&
  End If
End Function
